@@ -9,3 +9,7 @@ import unittest
 
 class controllers_test(unittest.TestCase):
     pass
+
+
+if __name__ == '__main__':
+    unittest.main()
